@@ -186,9 +186,12 @@ def reconciled(product):
     # compare fuped customers in aiguillier and fup-services databases
     if not product:
         fuped_aiguiller = core.get_fuped_aiguiller()
-        customers_aiguiller = [customer['name'] for customer in
-                               fuped_aiguiller]
+        customers_aiguiller = [
+            customer['name']
+            for customer in fuped_aiguiller
+        ]
         customers_si = core.get_customers_si()
+        customers_si = [customer['name'] for customer in customers_si]
 
         common_customers = set(customers_aiguiller) & set(customers_si)
         unfuped = [
