@@ -21,7 +21,7 @@ from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 from email.utils import formatdate
 
-from .consts import FUPDB_CREDENTIALS, APIGW, LOGS
+from .consts import FUPDB_CREDENTIALS, APIGW, LOGS, CONFIG
 
 import records
 import psycopg2
@@ -58,11 +58,31 @@ def database_url(**kwargs):
     return url
 
 
+def si_database_url():
+    url = '{eng}://{user}:{password}@{host}:{port}/{name}'.format(
+        eng=CONFIG['DB']['engine'],
+        user=CONFIG['DB']['user'],
+        password=CONFIG['DB']['password'],
+        host=CONFIG['DB']['host'],
+        port=CONFIG['DB']['port'],
+        name=CONFIG['DB']['name'],
+    )
+    return url
+
+
 def get_fuped_aiguiller():
+    """
+    Fetches all fuped customers in Aiguiller.
+    The called API returns both BI and SI customers and results need to be
+    filtered accordingly.
+    """
     try:
         response = requests.get(
-            'http://aiguillier.malagasy.com/rest/fup',
-            auth=("si", "cZ1Yw8SGCS2wIk4tUrl6YA833zI6SUOX3DeT5665")
+            CONFIG['AIGUILLIER']['url'] + '/fup',
+            auth=(
+                CONFIG['AIGUILLIER']['username'],
+                CONFIG['AIGUILLIER']['password'],
+            )
         )
         return response.json()['fup']
     except Exception as e:
@@ -78,8 +98,7 @@ def get_fuped_aiguiller():
 def get_customers_si():
     """Fetches fup-able customers in fup-service database."""
     try:
-        url = database_url()
-        with records.Database(url) as db:
+        with records.Database(si_database_url()) as db:
             sql = ("SELECT * FROM customer")
             rows = db.query(sql)
             customer_l = rows.as_dict()
@@ -100,7 +119,7 @@ def get_last_history(customer_name):
     :param customer_name: name of the customer, already lowered
     """
     try:
-        with records.Database(database_url()) as db:
+        with records.Database(si_database_url()) as db:
             sql = (
                 "SELECT * FROM fup "
                 "WHERE datetime = "
